import setuptools

setuptools.setup(
    name="tdp",
    version="0.1.0",
    license="MIT",
    author="taekop",
    author_email="taekop@naver.com",
    description="Hello",
    long_description="Hello",
    long_description_content_type="text/markdown",
    url="https://github.com/taekop/tdp",
    packages=setuptools.find_packages(),
    keywords="tdp",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[],
    python_requires=">=3.9,<4.0",
)
